@@ -4,6 +4,7 @@ An asynchronous client for Google Cloud KMS
 import io
 import json
 import os
+from typing import Any
 from typing import Dict
 from typing import Optional
 from typing import Union
@@ -16,7 +17,7 @@ from gcloud.aio.auth import Token  # pylint: disable=no-name-in-module
 if BUILD_GCLOUD_REST:
     from requests import Session
 else:
-    from aiohttp import ClientSession as Session
+    from aiohttp import ClientSession as Session  # type: ignore[no-redef]
 
 
 API_ROOT = 'https://cloudkms.googleapis.com/v1'
@@ -29,6 +30,7 @@ KMS_EMULATOR_HOST = os.environ.get('KMS_EMULATOR_HOST')
 if KMS_EMULATOR_HOST:
     API_ROOT = f'http://{KMS_EMULATOR_HOST}/v1'
 
+
 class KMS:
     def __init__(self, keyproject: str, keyring: str, keyname: str,
                  service_file: Optional[Union[str, io.IOBase]] = None,
@@ -80,11 +82,11 @@ class KMS:
         ciphertext: str = (await resp.json())['ciphertext']
         return ciphertext
 
-    async def close(self):
+    async def close(self) -> None:
         await self.session.close()
 
     async def __aenter__(self) -> 'KMS':
         return self
 
-    async def __aexit__(self, *args) -> None:
+    async def __aexit__(self, *args: Any) -> None:
         await self.close()
